<?php
if (!function_exists('decents_blog_posted_on')):
    /**
     * Prints HTML with meta information for the current post-date/time.
     */
    function decents_blog_posted_on()
    {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
        if (get_the_time('U') !== get_the_modified_time('U'))
        {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
        }

        $time_string = sprintf($time_string, esc_attr(get_the_date(DATE_W3C)) , esc_html(get_the_date()) , esc_attr(get_the_modified_date(DATE_W3C)) , esc_html(get_the_modified_date()));

        $posted_on = sprintf(
        /* translators: %s: post date. */
        esc_html('%s', 'post date', 'decents-blog') , '<a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a>');

        echo '<span class="posted-on">' . $posted_on . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        
    }
endif;

if (!function_exists('decents_blog_posted_by')):
    /**
     * Prints HTML with meta information for the current author.
     */
    function decents_blog_posted_by()
    {
        $byline = sprintf(
        /* translators: %s: post author. */
        esc_html('by %s', 'post author', 'decents-blog') , '<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author()) . '</a></span>');

        echo '<span class="byline"> ' . $byline . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        
    }
endif;

if (!function_exists('decents_blog_entry_footer')):
    /**
     * Prints HTML with meta information for the categories, tags and comments.
     */
    function decents_blog_entry_footer()
    {
        // Hide category and tag text for pages.
        if ('post' === get_post_type())
        {
            /* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list(esc_html__(', ', 'decents-blog'));
            if ($categories_list)
            {
                /* translators: 1: list of categories. */
                printf('<span class="cat-links">' . esc_html__('Posted in %1$s', 'decents-blog') . '</span>', $categories_list); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                
            }

            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list('', esc_html_x(', ', 'list item separator', 'decents-blog'));
            if ($tags_list)
            {
                /* translators: 1: list of tags. */
                printf('<span class="tags-links">' . esc_html__('Tagged %1$s', 'decents-blog') . '</span>', $tags_list); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                
            }
        }
    }
endif;

if (!function_exists('decents_blog_entry_comments')):
    function decents_blog_entry_comments()
    {

        if (!is_single() && !post_password_required() && (comments_open() || get_comments_number()))
        {
            echo '<span class="comments-link">';
            comments_popup_link(sprintf(wp_kses(
            /* translators: %s: post title */
            __('Leave a Comment<span class="screen-reader-text"> on %s</span>', 'decents-blog') , array(
                'span' => array(
                    'class' => array() ,
                ) ,
            )) , wp_kses_post(get_the_title())));
            echo '</span>';
        }

    }
endif;

if (!function_exists('decents_blog_post_thumbnail')):
    /**
     * Displays an optional post thumbnail.
     *
     * Wraps the post thumbnail in an anchor element on index views, or a div
     * element when on single views.
     */
    function decents_blog_post_thumbnail()
    {
        if (post_password_required() || is_attachment() || !has_post_thumbnail())
        {
            return;
        }

        if (is_singular()):
?>

            <div class="post-thumbnail">
                <?php the_post_thumbnail(); ?>
            </div><!-- .post-thumbnail -->

        <?php
        else: ?>

            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                <?php
            the_post_thumbnail('post-thumbnail', array(
                'alt' => the_title_attribute(array(
                    'echo' => false,
                )) ,
            ));
?>
            </a>

            <?php
        endif; // End is_singular().
        
    }
endif;

if (!function_exists('wp_body_open')):
    function wp_body_open()
    {
        do_action('wp_body_open');
    }
endif;

function decents_blog_excerpt_more($more)
{
    $more = '...';
    if (is_admin())
    {
        return $more;
    }
}
add_filter('excerpt_more', 'decents_blog_excerpt_more');